@@ -1,4 +1,4 @@
-/*	$Id: kcgi.h,v 1.124 2018/06/19 09:20:30 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.128 2018/12/27 21:00:53 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014--2018 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -53,7 +53,7 @@
 /*
  * Build version.
  */
-#define	KCGI_VBUILD	7
+#define	KCGI_VBUILD	10
 
 /*
  * Version string of major.minor.build (as a literal string).
@@ -616,6 +616,8 @@ char		*kutil_urlpart(struct kreq *, const char *,
 char		*kutil_urlpartx(struct kreq *, const char *,
 			const char *, const char *, ...);
 char		*kutil_urlencode(const char *);
+enum kcgi_err	 kutil_urldecode(const char *, char **);
+enum kcgi_err	 kutil_urldecode_inplace(char *);
 void		 kutil_invalidate(struct kreq *, struct kpair *);
 
 int		 kutil_openlog(const char *);
